@@ -2,7 +2,7 @@ import random
 import itertools as it
 
 
-def grid(**kwargs):
+def grid(shuffle=True, progbar=None, **kwargs):
     """
     Generates a grid of settings.
 
@@ -14,24 +14,24 @@ def grid(**kwargs):
     ```python
     from memo import grid
 
-    settings = list(grid(a=[1,2], b=[1, 2]))
+    settings = grid(a=[1,2], b=[1, 2], shuffle=False)
     expected = [
-         {'a': 1, 'b': 1},
-         {'a': 1, 'b': 2},
-         {'a': 2, 'b': 1},
-         {'a': 2, 'b': 2}
+        {'a': 1, 'b': 1},
+        {'a': 1, 'b': 2},
+        {'a': 2, 'b': 1},
+        {'a': 2, 'b': 2}
     ]
     assert settings == expected
-
-    def calc_sum(a, b):
-        return {"c": a + b}
-
-    for setting in settings:
-        print(calc_sum(**setting))
     ```
     """
-    for c in it.product(*[v for v in kwargs.values()]):
-        yield {k: v for k, v in zip(kwargs.keys(), c)}
+    settings = [
+        dict(zip(kwargs.keys(), d)) for d in it.product(*[v for v in kwargs.values()])
+    ]
+    if progbar:
+        raise DeprecationWarning("`progbar` is deprecated, use a `from memo import Runner` to get a progbar.")
+    if shuffle:
+        random.shuffle(settings)
+    return settings
 
 
 def random_grid(n=30, **kwargs):
@@ -46,9 +46,8 @@ def random_grid(n=30, **kwargs):
     ```python
     from memo import random_grid
 
-    settings = list(random_grid(n=30, a=[1,2], b=[1, 2]))
+    settings = random_grid(n=30, a=[1,2], b=[1, 2])
     assert len(settings) == 30
     ```
     """
-    for i in range(n):
-        yield {k: random.choice(v) for k, v in kwargs.items()}
+    return [{k: random.choice(v) for k, v in kwargs.items()} for _ in range(n)]
